==> jc-1.4.0.tar.gz: ppg/code/Code.h <==
// public abstract class ppg.code.Code

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_code_Code_H_
#define _JC_ppg_code_Code_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_Code$sub_refs	_jc_ppg_code_Code$sub_refs;
typedef struct _jc_ppg_code_Code$sub_nonrefs	_jc_ppg_code_Code$sub_nonrefs;
typedef struct _jc_ppg_code_Code$refs	_jc_ppg_code_Code$refs;
typedef struct _jc_ppg_code_Code$nonrefs	_jc_ppg_code_Code$nonrefs;
typedef struct _jc_ppg_code_Code$object	_jc_ppg_code_Code$object;

typedef const struct _jc_ppg_code_Code$vmethods	_jc_ppg_code_Code$vmethods;
typedef const struct _jc_ppg_code_Code$vtable	_jc_ppg_code_Code$vtable;
typedef const struct _jc_ppg_code_Code$vtype	_jc_ppg_code_Code$vtype;

// Constructors
extern void _jc_ppg_code_Code$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_code_Code$object *);

// Virtual methods
extern void _jc_ppg_code_Code$method$append$e81cc402fc833404(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Object$object *_jc_ppg_code_Code$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_Code$object *);
extern void _jc_ppg_code_Code$method$prepend$8da17169eb296f99(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_code_Code$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_Code$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_code_Code$method_info$append$e81cc402fc833404;
extern _jc_method _jc_ppg_code_Code$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_Code$method_info$prepend$8da17169eb296f99;
extern _jc_method _jc_ppg_code_Code$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_Code$vmethods {
	void	(*append$e81cc402fc833404)(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_Code$object *);
	void	(*prepend$8da17169eb296f99)(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_Code$object *);
};

// Vtable
struct _jc_ppg_code_Code$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
};

// Vtype
struct _jc_ppg_code_Code$vtype {
	_jc_type			type;
	_jc_ppg_code_Code$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_Code$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_ppg_code_Code$refs {
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_Code$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_Code$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
};

// Object instance structure
struct _jc_ppg_code_Code$object {
	_jc_ppg_code_Code$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_Code$vtype	*vtype;
	_jc_ppg_code_Code$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_Code$vtype _jc_ppg_code_Code$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_Code, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_Code$class_object;

#endif	/* _JC_ppg_code_Code_H_ */

==> jc-1.4.6.tar.gz: ppg/code/Code.h <==
// public abstract class ppg.code.Code

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_code_Code_H_
#define _JC_ppg_code_Code_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_Code$sub_refs	_jc_ppg_code_Code$sub_refs;
typedef struct _jc_ppg_code_Code$sub_nonrefs	_jc_ppg_code_Code$sub_nonrefs;
typedef struct _jc_ppg_code_Code$refs	_jc_ppg_code_Code$refs;
typedef struct _jc_ppg_code_Code$nonrefs	_jc_ppg_code_Code$nonrefs;
typedef struct _jc_ppg_code_Code$object	_jc_ppg_code_Code$object;

typedef const struct _jc_ppg_code_Code$vmethods	_jc_ppg_code_Code$vmethods;
typedef const struct _jc_ppg_code_Code$vtable	_jc_ppg_code_Code$vtable;
typedef const struct _jc_ppg_code_Code$vtype	_jc_ppg_code_Code$vtype;

// Constructors
extern void _jc_ppg_code_Code$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_ppg_code_Code$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_ppg_code_Code$method$append$e81cc402fc833404(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_ppg_code_Code$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_Code$object *) _JC_JCNI_ATTR;
extern void _jc_ppg_code_Code$method$prepend$8da17169eb296f99(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_code_Code$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_Code$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_code_Code$method_info$append$e81cc402fc833404;
extern _jc_method _jc_ppg_code_Code$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_Code$method_info$prepend$8da17169eb296f99;
extern _jc_method _jc_ppg_code_Code$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_Code$vmethods {
	void	(*append$e81cc402fc833404)(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_Code$object *) _JC_JCNI_ATTR;
	void	(*prepend$8da17169eb296f99)(_jc_env *, struct _jc_ppg_code_Code$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_Code$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_code_Code$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
};

// Vtype
struct _jc_ppg_code_Code$vtype {
	_jc_type			type;
	_jc_ppg_code_Code$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_Code$sub_refs {
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_ppg_code_Code$refs {
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_Code$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_Code$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
};

// Object instance structure
struct _jc_ppg_code_Code$object {
	_jc_ppg_code_Code$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_Code$vtype	*vtype;
	_jc_ppg_code_Code$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_Code$vtype _jc_ppg_code_Code$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_Code, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_Code$class_object;

#endif	/* _JC_ppg_code_Code_H_ */
